==> fred-ferda-3.13.2.tar.gz: fred-ferda-3.13.2/jest.config.js <==
module.exports = {
    testEnvironment: '<rootDir>/tests-js/helpers/jsdom-with-time-zone.js',
    testMatch: ['<rootDir>/tests-js/**/*.test.js'],
    moduleFileExtensions: ['js', 'vue'],
    transform: {
        '^.+\\.js$': '<rootDir>/node_modules/babel-jest',
        '^.+\\.vue$': '<rootDir>/node_modules/vue-jest',
    },
    snapshotSerializers: ['<rootDir>/node_modules/jest-serializer-vue'],
    transformIgnorePatterns: ['node_modules/(?!(@cz-nic/django-fido))'],
    moduleNameMapper: {
        '\\.(jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga)$':
            '<rootDir>/tests-js/__mocks__/fileMock.js',
        '\\.(css|less)$': 'identity-obj-proxy',
        '^~FerdaCSS/(.*)$': '<rootDir>/assets/scss/$1',
        '^~FerdaJS/(.*)$': '<rootDir>/assets/js/$1',
        '^ferda/(.*)$': '<rootDir>/assets/js/components/$1',
        '^ferda-test/(.*)$': '<rootDir>/tests-js/$1',
    },
    setupFilesAfterEnv: ['<rootDir>/tests-js/helpers/setup-vue.js', '<rootDir>/tests-js/helpers/override-errors.js'],
    collectCoverage: true,
    collectCoverageFrom: [
        'assets/js/**/*.{js,vue}',
        '!assets/js/app.base.js',
        '!assets/js/app.registry.js',
        '!assets/js/app.messaging.js',
        '!assets/js/app.reporting.js',
        '!assets/js/app.logger.js',
        '!assets/js/app.config.js',
        '!assets/js/components/logger/router.js',
        '!assets/js/components/Urls.js',
        '!assets/js/components/utils.js',
    ],
    coverageDirectory: 'coverage-js',
    coverageReporters: ['text', 'text-summary', 'json-summary'],
}

==> fred-ferda-3.15.0.tar.gz: fred-ferda-3.15.0/jest.config.js <==
module.exports = {
    testEnvironment: '<rootDir>/tests-js/helpers/jsdom-with-time-zone.js',
    testMatch: ['<rootDir>/tests-js/**/*.test.js'],
    moduleFileExtensions: ['js', 'vue'],
    transform: {
        '^.+\\.js$': '<rootDir>/node_modules/babel-jest',
        '^.+\\.vue$': '<rootDir>/node_modules/vue-jest',
    },
    snapshotSerializers: ['<rootDir>/node_modules/jest-serializer-vue'],
    transformIgnorePatterns: ['node_modules/(?!(@cz-nic/django-fido))'],
    moduleNameMapper: {
        '\\.(jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga)$':
            '<rootDir>/tests-js/__mocks__/fileMock.js',
        '\\.(css|less)$': 'identity-obj-proxy',
        '^~FerdaCSS/(.*)$': '<rootDir>/assets/scss/$1',
        '^~FerdaJS/(.*)$': '<rootDir>/assets/js/$1',
        '^ferda/(.*)$': '<rootDir>/assets/js/components/$1',
        '^ferda-test/(.*)$': '<rootDir>/tests-js/$1',
    },
    setupFilesAfterEnv: [
        '<rootDir>/tests-js/helpers/setup-vue.js',
        '<rootDir>/tests-js/helpers/override-errors.js',
        '<rootDir>/tests-js/helpers/polyfill.js',
    ],
    collectCoverage: true,
    collectCoverageFrom: [
        'assets/js/**/*.{js,vue}',
        '!assets/js/app.base.js',
        '!assets/js/app.registry.js',
        '!assets/js/app.messaging.js',
        '!assets/js/app.reporting.js',
        '!assets/js/app.logger.js',
        '!assets/js/app.config.js',
        '!assets/js/router/logger/index.js',
        '!assets/js/router/registry/index.js',
        '!assets/js/components/Urls.js',
        '!assets/js/components/utils.js',
    ],
    coverageDirectory: 'coverage-js',
    coverageReporters: ['text', 'text-summary', 'json-summary'],
}
